==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/BollingerBandWidthIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { BollingerBandWidthIndicatorDescription } from "./BollingerBandWidthIndicatorDescription";
/**
 * @hidden
 */
export let BollingerBandWidthIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (BollingerBandWidthIndicatorDescriptionMetadata.a == null) {
                BollingerBandWidthIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BollingerBandWidthIndicatorDescriptionMetadata.c(BollingerBandWidthIndicatorDescriptionMetadata.a);
            }
            if (a.k(BollingerBandWidthIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(BollingerBandWidthIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
            a.item("Multiplier", "Number:double");
        }
        static d(a) {
            BollingerBandWidthIndicatorDescriptionMetadata.b(a);
            a.ad("BollingerBandWidthIndicator", () => new BollingerBandWidthIndicatorDescription());
            a.ac("BollingerBandWidthIndicator", BollingerBandWidthIndicatorDescriptionMetadata.a);
        }
    }
    BollingerBandWidthIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(BollingerBandWidthIndicatorDescriptionMetadata, 'BollingerBandWidthIndicatorDescriptionMetadata');
    BollingerBandWidthIndicatorDescriptionMetadata.a = null;
    return BollingerBandWidthIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/BollingerBandWidthIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { BollingerBandWidthIndicatorDescription } from "./BollingerBandWidthIndicatorDescription";
/**
 * @hidden
 */
export let BollingerBandWidthIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class BollingerBandWidthIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (BollingerBandWidthIndicatorDescriptionMetadata.a == null) {
                BollingerBandWidthIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BollingerBandWidthIndicatorDescriptionMetadata.c(BollingerBandWidthIndicatorDescriptionMetadata.a);
            }
            if (a.k(BollingerBandWidthIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(BollingerBandWidthIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
            a.item("Multiplier", "Number:double");
        }
        static d(a) {
            BollingerBandWidthIndicatorDescriptionMetadata.b(a);
            a.ae("BollingerBandWidthIndicator", () => new BollingerBandWidthIndicatorDescription());
            a.ad("BollingerBandWidthIndicator", BollingerBandWidthIndicatorDescriptionMetadata.a);
        }
    }
    BollingerBandWidthIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(BollingerBandWidthIndicatorDescriptionMetadata, 'BollingerBandWidthIndicatorDescriptionMetadata');
    BollingerBandWidthIndicatorDescriptionMetadata.a = null;
    return BollingerBandWidthIndicatorDescriptionMetadata;
})();
